#!/bin/sh

PATH=/bin:/sbin:/usr/bin:/bin:/usr/sbin:/usr/local/bin
export PATH

SP="SP1"

lng=$1
case $lng in
   local) ;;
   de) ;;
   en) ;;
   *) lng="de" ;;
esac

update() {
   rm -f /tmp/REBOOT

   if [ ! -x /usr/bin/opkg -a -x /usr/bin/opkg-cl ]; then
      ln /usr/bin/opkg-cl /usr/bin/opkg
   fi

   if [ ! -x /usr/bin/opkg ]; then
      echo "================================================================="
      echo "===== es fehlt das Programm 'opkg' fr den Updateprozess! ======="
      echo "================================================================="

      case $lng in
	 de) lcdmsg -m "OPKG ist nicht\ninstalliert!" ;;
	 en) lcdmsg -m "OPKG is not\ninstalled!" ;;
      esac
      sleep 3

      exit 1
   fi

   # laufende Prozesse beenden
   if [ -f /var/run/eccweb.pid ]; then
      /sbin/start-stop-daemon -K -q -p /var/run/eccweb.pid
   fi
   if [ -f /var/run/ecc_core.pid ]; then
      /sbin/start-stop-daemon -K -q -p /var/run/ecc_core.pid
   fi
   if [ -f /var/run/ecc_modbus.pid ]; then
      /sbin/start-stop-daemon -K -q -p /var/run/ecc_modbus.pid
   fi
   if [ -f /var/run/ecc_bacnet.pid ]; then
      /sbin/start-stop-daemon -K -q -p /var/run/ecc_bacnet.pid
   fi
   if [ -f /var/run/ecc_knx.pid ]; then
      /sbin/start-stop-daemon -K -q -p /var/run/ecc_knx.pid
   fi

   for pkg in *.opk; do
      /usr/bin/opkg install --force-downgrade ${pkg}
   done
   /bin/gunzip < package.gz | /bin/tar -xvf - -C /
   /usr/sbin/ldconfig

   case $lng in
      de) lcdmsg -m "... Speichern wird\nabgeschlossen" ;;
      en) lcdmsg -m "... finishing\nstorage operation" ;;
   esac
   /bin/sync

   touch /etc/${SP}
   touch /tmp/REBOOT
   case $lng in
      de) lcdmsg -m "fertig... Neustart\nnach Stick abziehen" ;;
      en) lcdmsg -m "ready... restart\nafter removing Stick" ;;
   esac
}

rc=0
echo "Running Update Check"

if [ -x /usr/bin/lcdmsg ]; then

   if [ -f /etc/${SP} ]; then
      if [ "$lng" = "local" ]; then
         echo "${SP} already installed ... give up"
	 exit 0
      else
	 killall lcd_manager
	 case $lng in
	    de) lcdmsg -m "Service-Pack ${SP}\nist bereits\ninstalliert" -c "Abbruch"
		;;
	    en) lcdmsg -m "Service-Pack ${SP}\nalready installed" -c "Cancel"
		;;
	 esac
	 exit 0
      fi
   fi

   if [ "$lng" = "local" ]; then
      rc=0
   else
      killall lcd_manager
      case $lng in
	 de) lcdmsg -m "Mchten Sie das\nService-Pack ${SP}\ninstallieren?" -c "Abbruch" -o "UPDATE"
	     rc=$?
	     ;;
	 en) lcdmsg -m "Would you like to\ninstall the\nService-Pack ${SP}?" -c "Cancel" -o "UPDATE"
	     rc=$?
	     ;;
      esac
      echo "Selection: $rc"
   fi

   case $rc in
      0) case $lng in
            de) lcdmsg -m "${SP} wird installiert" ;;
            en) lcdmsg -m "${SP} is installing" ;;
	 esac
	 update
	 ;;
      *) case $lng in
      	    de) lcdmsg -m "Abgebrochen ...\nbitte Stick abziehen" ;;
      	    en) lcdmsg -m "Aborted ...\nplease remove Stick" ;;
	 esac
	 rc=2
	 ;;
   esac
else

   echo "================================================================="
   echo "==== es fehlt das Programm 'lcdmsg' fr den Updateprozess! ======"
   echo "================================================================="

   exit 1

fi

chmod 755 /etc/init.d/S*

sync
echo "... FINISHED ..."

exit $rc
